## berliner
Tools for stellar tracks & isochrones.

## author
Bo Zhang, [bozhang@nao.cas.cn](mailto:bozhang@nao.cas.cn)

## home page
- [https://github.com/hypergravity/berliner](https://github.com/hypergravity/berliner)
- [https://pypi.org/project/berliner/](https://pypi.org/project/berliner/)

## install
- for the latest **stable** version: `pip install berliner`
- for the latest **github** version: `pip install git+git://github.com/hypergravity/berliner`

## acknowledgements
The *ezpadova* package is from Morgan Fouesneau, which could be found in [https://github.com/mfouesneau/ezpadova](https://github.com/mfouesneau/ezpadova) [downloaded on 2018.12.27].
Since it is not on **PYPI** and could not be installed automatically, I included it here.
